@@ -31,7 +31,7 @@ BEGIN {
 @ISA         = qw( Exporter );
 %EXPORT_TAGS = (
    macro => [qw( isaref      ishref      )],
-   util  => [qw( binary_mode DIGEST trim escape )],
+   util  => [qw( binary_mode DIGEST trim rtrim ltrim escape )],
    debug => [qw( fatal       DEBUG  LOG  )],
 );
 @EXPORT_OK        = map { @{ $EXPORT_TAGS{$_} } } keys %EXPORT_TAGS;
@@ -87,6 +87,20 @@ sub trim {
    return $s;
 }
 
+sub ltrim {
+   my $s = shift;
+   return $s if ! $s; # false or undef
+      $s =~ s{\A \s+ }{}xms;
+   return $s;
+}
+
+sub rtrim {
+   my $s = shift;
+   return $s if ! $s; # false or undef
+      $s =~ s{ \s+ \z}{}xms;
+   return $s;
+}
+
 sub DEBUG {
    my $thing = shift;
 
@@ -189,6 +203,14 @@ Returns true if C<THING> is a HASH.
 
 Returns the trimmed version of the C<STRING>.
 
+=head2 ltrim STRING
+
+Returns the left trimmed version of the C<STRING>.
+
+=head2 rtrim STRING
+
+Returns the right trimmed version of the C<STRING>.
+
 =head2 escape CHAR, STRING
 
 Escapes all occurrances of C<CHAR> in C<STRING> with backslashes.
